@@ -413,6 +413,20 @@ int ConsolePlayer::args(int argc, const char *argv[])
                     m_frange = atof(&argv[i][9]);
                 }
             }
+#endif
+#ifdef FEAT_CW_STRENGTH
+            else if (std::strcmp (&argv[i][1], "cww") == 0)
+            {
+                m_combinedWaveformsStrength  = SidConfig::WEAK;
+            }
+            else if (std::strcmp (&argv[i][1], "cwa") == 0)
+            {
+                m_combinedWaveformsStrength  = SidConfig::AVERAGE;
+            }
+            else if (std::strcmp (&argv[i][1], "cws") == 0)
+            {
+                m_combinedWaveformsStrength  = SidConfig::STRONG;
+            }	
 #endif
             // File format conversions
             else if (argv[i][1] == 'w')
@@ -691,6 +705,9 @@ void ConsolePlayer::displayArgs (const char *arg)
         << " --fcurve=<num>|auto Controls the filter curve in the ReSIDfp emulation (0.0 to 1.0, default: 0.5)" << endl
 #ifdef FEAT_FILTER_RANGE
         << " --frange=<num>|auto Controls the filter range in the ReSIDfp emulation (0.0 to 1.0, default: 0.5)" << endl
+#endif
+#ifdef FEAT_CW_STRENGTH
+        << " -cw<w|a|s>   Set the strength of combined waveforms, w(eak), a(verage) or s(trong)" << endl
 #endif
         << " -w[name]     create wav file (default: <datafile>[n].wav)" << endl
         << " --au[name]   create au file (default: <datafile>[n].au)" << endl
