@@ -59,16 +59,19 @@ private:  // ------------------------------------------------------- private
     static   const char AUDIODEVICE[];
     volatile int   _audiofd;
 
+    int m_frameSize;
+
+private:
     void outOfOrder ();
 
 public:  // --------------------------------------------------------- public
     Audio_OSS();
-    ~Audio_OSS();
+    ~Audio_OSS() override;
 
     bool open  (AudioConfig &cfg) override;
     void close () override;
     void reset () override;
-    bool write (uint_least32_t size) override;
+    bool write (uint_least32_t frames) override;
     void pause () override {}
 };
 
