@@ -89,6 +89,11 @@ static char keytable[] =
     '7',0,                  A_TOGGLE_VOICE7,
     '8',0,                  A_TOGGLE_VOICE8,
     '9',0,                  A_TOGGLE_VOICE9,
+#ifdef FEAT_SAMPLE_MUTE
+    'q',0,                  A_TOGGLE_SAMPLE1,
+    'w',0,                  A_TOGGLE_SAMPLE2,
+    'e',0,                  A_TOGGLE_SAMPLE3,
+#endif
     'f',0,                  A_TOGGLE_FILTER,
 
     // General Keys
@@ -110,11 +115,7 @@ static char keytable[] =
  */
 static int keyboard_search (char *cmd)
 {
-    char *p;
-    char *q;
-    int   a;
-
-    for (p = keytable, q = cmd;;  p++, q++)
+    for (char *p = keytable, *q = cmd;;  p++, q++)
     {
         if (*p == *q)
         {
@@ -127,7 +128,7 @@ static int keyboard_search (char *cmd)
              */
             if (*p == '\0')
             {
-                a = *++p & 0377;
+                int a = *++p & 0377;
                 while (a == A_SKIP)
                     a = *++p & 0377;
                 if (a == A_END_LIST)
@@ -251,9 +252,6 @@ int _getch (void)
 static termios term;
 void keyboard_enable_raw ()
 {
-    // set to non canonical mode, echo off, ignore signals
-    struct termios current;
-
     // Already open
     if (infd >= 0)
         return;
@@ -271,6 +269,7 @@ void keyboard_enable_raw ()
     }
 
     // save current terminal settings
+    struct termios current;
     tcgetattr (infd, &current);
 
     // set to non canonical mode, echo off, ignore signals
