@@ -26,8 +26,6 @@
 #  include "config.h"
 #endif
 
-#include <string>
-
 #include <sidplayfp/SidTune.h>
 #include <sidplayfp/sidplayfp.h>
 #include <sidplayfp/SidConfig.h>
@@ -41,6 +39,9 @@
 
 #include "sidlib_features.h"
 
+#include <string>
+#include <bitset>
+
 #ifdef HAVE_TSID
 #  if HAVE_TSID > 1
 #    include <tsid2/tsid2.h>
@@ -113,13 +114,6 @@ enum class output_t
     END
 };
 
-// Error and status message numbers.
-enum class errnum_t
-{
-    NOT_ENOUGH_MEMORY,
-    SIGHANDLER
-};
-
 // Songlength DB.
 enum class sldb_t
 {
@@ -128,9 +122,6 @@ enum class sldb_t
     MD5
 };
 
-void displayError (const char *arg0, errnum_t num);
-
-
 // Grouped global variables
 class ConsolePlayer
 {
@@ -163,6 +154,9 @@ private:
     SidDatabase        m_database;
 
     double             m_fcurve;
+#ifdef FEAT_FILTER_RANGE
+    double             m_frange;
+#endif
 
 #ifdef FEAT_CW_STRENGTH
     SidConfig::sid_cw_t m_combinedWaveformsStrength;
@@ -181,10 +175,14 @@ private:
 
     bool               m_autofilter;
 
-    bool vMute[9];
+    std::bitset<9>     m_mute_channel;
+#ifdef FEAT_SAMPLE_MUTE
+    std::bitset<3>     m_mute_samples;
+#endif
 
     int  m_channels;
     int  m_precision;
+    int  m_buffer_size;
 
     struct m_filter_t
     {
@@ -248,8 +246,6 @@ private:
 
     bool createOutput   (output_t driver, const SidTuneInfo *tuneInfo);
     bool createSidEmu   (SIDEMUS emu, const SidTuneInfo *tuneInfo);
-    void displayError   (const char *error);
-    void displayError   (errnum_t num) { ::displayError (m_name, num); }
     void decodeKeys     (void);
     void updateDisplay();
     void emuflush       (void);
@@ -269,6 +265,8 @@ public:
     ConsolePlayer (const char * const name);
     virtual ~ConsolePlayer() = default;
 
+    void displayError(const char *error);
+
     int  args  (int argc, const char *argv[]);
     bool open  (void);
     void close (void);
