@@ -37,10 +37,7 @@
 #endif
 
 #ifndef HAVE_CXX11
-#  define nullptr    0
-#  define override
-#  define final
-#  define unique_ptr auto_ptr
+#  error "This is not a C++11 compiler"
 #endif
 
 #endif
